@@ -5,14 +5,14 @@ use strict;
 
 =head1 NAME
 
-Acme::MyFirstModule::WWILLIS - The great new Acme::MyFirstModule::WWILLIS!
+Acme::MyFirstModule::WWILLIS - The great old Acme::MyFirstModule::WWILLIS!
 
 =head1 VERSION
 
-Version 0.01
+Version 0.03
 
 =cut
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -52,11 +52,7 @@ Will Willis, C<< <wwillis at cpan.org> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to
-C<bug-acme-myfirstmodule-wwillis at rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Acme-MyFirstModule-WWILLIS>.
-I will be notified, and then you'll automatically be notified of progress on
-your bug as I make changes.
+Yes, very likely.
 
 =head1 SUPPORT
 
@@ -90,7 +86,7 @@ L<http://search.cpan.org/dist/Acme-MyFirstModule-WWILLIS>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2014 Will Willis, all rights reserved.
+Copyright 2023 Will Willis, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
